"""
Binance Pay REST API

OpenAPI Specification for the Binance Pay REST API
The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from .pay_api import PayApi as PayApi
